TransitionModelLinearNoControl

Trait TransitionModelLinearNoControl 

pub trait TransitionModelLinearNoControl<R, SS>
where R: RealField, SS: Dim, DefaultAllocator: Allocator<SS, SS> + Allocator<SS>,
{ // Required methods fn F(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>; fn FT(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>; fn Q(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>; // Provided method fn predict( &self, previous_estimate: &StateAndCovariance<R, SS>, ) -> StateAndCovariance<R, SS> { ... } }
A linear model of process dynamics with no control inputs

Required Methods

fn F(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>

Get the state transition model, F.

fn FT(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>

Get the transpose of the state transition model, FT.

fn Q(&self) -> &Matrix<R, SS, SS, Owned<R, SS, SS>>

Get the process covariance, Q.

Provided Methods

fn predict( &self, previous_estimate: &StateAndCovariance<R, SS>, ) -> StateAndCovariance<R, SS>

Predict new state from previous estimate.

Implementors